/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.creation;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.image.IcyBufferedImage;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarSequence;

/**
 * @author Thomas Provoost
 */
@IcyPluginName("Create Sequence")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class CreateSequence extends Plugin implements SequenceBlock {
    final protected Var<IcyBufferedImage> in = new Var<>("image (optional)", IcyBufferedImage.class);
    final protected VarSequence out = new VarSequence("sequence", null);

    @Override
    public void run() {
        out.setValue(new Sequence(in.getValue()));
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("image (optional)", in);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("sequence", out);
    }
}
