/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.files;

import ome.xml.meta.OMEXMLMetadata;
import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.io.Loader;
import org.bioimageanalysis.icy.model.sequence.MetaDataUtil;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.lang.VarMutable;
import plugins.adufour.vars.util.VarException;

import java.io.File;

/**
 * Block to load Sequence metadata from a file
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Load Metadata")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class LoadMetadata extends Plugin implements SequenceBlock {
    final protected VarMutable f_in = new VarMutable("File", null) {
        @Override
        public boolean isAssignableFrom(final @NotNull Var source) {
            return (String.class == source.getType()) || (File.class == source.getType());
        }
    };
    final protected Var<OMEXMLMetadata> output = new Var<>("Metadata", OMEXMLMetadata.class);
    final protected VarInteger numSerie = new VarInteger("Series number", 1);

    @Override
    public void run() {
        final Object obj = f_in.getValue();
        if (obj != null) {
            final File f;

            if (obj instanceof String)
                f = new File((String) obj);
            else
                f = (File) obj;

            try {
                final OMEXMLMetadata meta = Loader.getOMEXMLMetaData(f.getAbsolutePath());

                if (meta != null) {
                    output.setValue(meta);
                    numSerie.setValue(MetaDataUtil.getNumSeries(meta));
                }
            }
            catch (final Exception e) {
                throw new VarException(null, e.getMessage());
            }
        }
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("file", f_in);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("Metadata", output);
        outputMap.add("Serie number", numSerie);
    }
}
