/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.importer;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.io.SequenceFileImporter;
import org.bioimageanalysis.icy.model.image.IcyBufferedImage;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.io.IOBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.util.VarException;

/**
 * Block to returns a thumbnail from the specified opened SequenceFileImporter.
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Get Thumbnail from SequenceFileImporter")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class SequenceFileImporterGetThumbnail extends Plugin implements IOBlock {
    final protected Var<PositionedSequenceFileImporter> importer;
    final protected VarInteger series;
    final protected Var<IcyBufferedImage> thumbnail;

    public SequenceFileImporterGetThumbnail() {
        super();

        importer = new Var<>("Importer", PositionedSequenceFileImporter.class);
        series = new VarInteger("Series", 0);
        thumbnail = new Var<>("Thumbnail", IcyBufferedImage.class);
    }

    @Override
    public void run() {
        final PositionedSequenceFileImporter pi = importer.getValue();

        if (pi == null)
            throw new VarException(importer, "Importer is null !");

        final SequenceFileImporter imp = pi.importer;

        if (imp.getOpened() == null)
            throw new VarException(importer, "Importer is not opened !");

        final int s = series.getValue();

        try {
            thumbnail.setValue(imp.getThumbnail(s));
        }
        catch (final Exception e) {
            throw new VarException(importer, e.getMessage());
        }
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("importer", importer);
        inputMap.add("series", series);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("thumbnail", thumbnail);
    }
}
