/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.infos;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.colormap.IcyColorMap;
import org.bioimageanalysis.icy.model.colormap.LinearColorMap;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.BlocksException;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.lang.VarSequence;

@IcyPluginName("Set Colormap")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class SetColormap extends Plugin implements SequenceBlock {
    final protected VarSequence sequenceIn = new VarSequence("Sequence", null);
    final protected VarInteger numChannel = new VarInteger("Channel", 0);
    final protected VarColormap colormap = new VarColormap("Color map", LinearColorMap.gray_);

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("input", sequenceIn);
        inputMap.add("numChannel", numChannel);
        inputMap.add("colormap", colormap);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        // no output here
    }

    @Override
    public void run() {
        final Sequence seq = sequenceIn.getValue();

        if (seq != null) {
            final int ch = numChannel.getValue();
            final IcyColorMap map = colormap.getValue();

            if ((ch < seq.getSizeC()) && (map != null))
                seq.setColormap(ch, map, map.isAlpha());
            else
                throw new BlocksException("Block 'Set Colormap': illegal channel number for this sequence !", true);
        }
    }
}
