/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.infos;

import org.bioimageanalysis.icy.gui.component.renderer.ColormapComboBoxRenderer;
import org.bioimageanalysis.icy.io.xml.XMLUtil;
import org.bioimageanalysis.icy.model.colormap.IcyColorMap;
import org.bioimageanalysis.icy.model.colormap.LinearColorMap;
import org.w3c.dom.Node;
import plugins.adufour.vars.gui.VarEditor;
import plugins.adufour.vars.gui.model.ValueSelectionModel;
import plugins.adufour.vars.gui.swing.ComboBox;
import plugins.adufour.vars.lang.Var;

import javax.swing.*;

/**
 * Define a specific Var type for ColorMap object
 *
 * @author Emilie
 */
public class VarColormap extends Var<IcyColorMap> {
    public static class ColormapSelectionModel extends ValueSelectionModel<IcyColorMap> {
        public ColormapSelectionModel() {
            super(IcyColorMap.getAllColorMaps(true, true).toArray(new IcyColorMap[0]), LinearColorMap.gray_, false);
        }

        @Override
        public boolean isValid(final IcyColorMap value) {
            return true;
        }
    }

    public final String ID_NODE = "colormap";

    /**
     * Create a new VarColormap with given name and default value
     *
     * @param name         String
     * @param defaultValue IcyColorMap
     */
    public VarColormap(final String name, final IcyColorMap defaultValue) {
        super(name, new ColormapSelectionModel());
    }

    @Override
    public VarEditor<IcyColorMap> createVarEditor() {
        // create the var editor (combo box type here)
        final ComboBox<IcyColorMap> result = new ComboBox<>(this);
        // get the editor component
        final JComboBox<IcyColorMap> combo = result.getEditorComponent();
        // and set a specific renderer
        combo.setRenderer(new ColormapComboBoxRenderer(combo));

        return result;
    }

    @Override
    public boolean loadFromXML(final Node node) {
        try {
            final IcyColorMap map = new IcyColorMap();
            map.loadFromXML(XMLUtil.setElement(node, ID_NODE));
            setValue(map);

            return true;
        }
        catch (final Exception e) {
            return false;
        }
    }

    @Override
    public boolean saveToXML(final Node node) throws UnsupportedOperationException {
        try {
            getValue().saveToXML(XMLUtil.setElement(node, ID_NODE));
            return true;
        }
        catch (final Exception e) {
            return false;
        }
    }
}
