/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.loop;

import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.bioimageanalysis.icy.model.sequence.SequenceUtil;
import plugins.adufour.blocks.lang.Batch;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;

/**
 * Simple batch loop to iterate over all C channel from an input Sequence.
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Sequence Channel Batch")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class SequenceChannelBatch extends Batch implements SequenceBlock {
    // important to not initialize here (even with null) and create them in getBatchSource() and getBatchElement()
    protected VarSequence inputSequence;
    protected VarSequence element;

    @Override
    public VarSequence getBatchSource() {
        // initialize variable if needed
        if (inputSequence == null)
            inputSequence = new VarSequence("Sequence", null);

        return inputSequence;
    }

    @Override
    public VarSequence getBatchElement() {
        // initialize element if needed
        if (element == null)
            element = new VarSequence("Channel Sequence", null);

        return element;
    }

    @Override
    public void initializeLoop() {
        final Sequence value = inputSequence.getValue();

        if (value == null)
            throw new VarException(inputSequence, "No input sequence indicated");
    }

    @Override
    public void beforeIteration() {
        try {
            // set result in element
            element.setValue(SequenceUtil.extractChannel(inputSequence.getValue(), getIterationCounter().getValue()));
        }
        catch (final InterruptedException e) {
            // nothing to do
        }
    }

    @Override
    public boolean isStopConditionReached() {
        return getIterationCounter().getValue() >= inputSequence.getValue().getSizeC();
    }
}
