/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.remove;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.bioimageanalysis.icy.model.sequence.SequenceUtil;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;

/**
 * Block to remove a channel from a Sequence
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Remove Channel")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class RemoveChannel extends Plugin implements SequenceBlock {
    final protected VarSequence inputSequence = new VarSequence("Sequence", null);
    final protected VarInteger channelIdx = new VarInteger("Channel", 0);

    @Override
    public void run() {
        final Sequence s = inputSequence.getValue();
        if (s == null)
            throw new VarException(inputSequence, "Input sequence is null.");
        if (s.getSizeC() == 1)
            throw new VarException(inputSequence, "Cannot remove channel on single channel image");

        final int channel = channelIdx.getValue();
        if (channel < 0 || channel >= s.getSizeC())
            throw new VarException(channelIdx, "Channel index must be between 0 and " + (s.getSizeC() - 1));

        try {
            SequenceUtil.removeChannel(s, channel);
        }
        catch (final InterruptedException e) {
            // nothing to do
        }
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("sequence", inputSequence);
        inputMap.add("channel", channelIdx);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        //
    }
}
